@@ -211,8 +211,9 @@ class Profile(object):
             pipe = cls.redis_client.pipeline()
             for p in profiles_from_db.values():
                 p.to_cache(key=p.profile_key, add_to_pool=True, pipe=pipe)
+
+            pipe.delete(cls._new_user_detected_key(user_id=user_id))
             pipe.execute()
-            cls.redis_client.delete(cls._new_user_detected_key(user_id=user_id))
 
             data_dict = {k: v for k, v in data_dict.items()
                          if not cls.profile_id_from_key(k.decode()) in profiles_from_db}
@@ -232,7 +233,7 @@ class Profile(object):
 
         if len(profiles) == 0:
             return None
-        if len(profiles) >= cls.fast_clean_threshold:
+        if len(profiles_from_db) >= cls.fast_clean_threshold:
             cls.user_in_cleaning_queue(user_id)
 
         return sum(profiles)
